@@ -20,7 +20,9 @@ class LoggerMiddleware:
         self.logger.debug("%s %s", req.method, req.relative_uri)
 
     def process_response(self, req, resp, *args, **kwargs):  # pyre-ignore
-        self.logger.info("%s %s - %s", req.method, req.relative_uri, resp.status)
+        tc = req.get_header("X-Test-Case")
+        test_case = "[%s] " % tc if tc else ""
+        self.logger.info("%s%s %s - %s", test_case, req.method, req.relative_uri, resp.status)
 
 
 def rest_handler(fn: Any):  # pyre-ignore
@@ -51,11 +53,11 @@ class Endpoints:
 
     @rest_handler
     def on_post_payments(self, account_id: str, input: JsonInput) -> Tuple[str, Dict[str, Any]]:
-        return (falcon.HTTP_202, asdict(self.app.create_account_payment(account_id, input)))
+        return (falcon.HTTP_202, self.app.create_account_payment(account_id, input))
 
     @rest_handler
-    def on_post_payment_uris(self, account_id: str, input: JsonInput) -> Tuple[str, Dict[str, Any]]:
-        return (falcon.HTTP_200, asdict(self.app.create_account_payment_uri(account_id, input)))
+    def on_post_account_identifiers(self, account_id: str, input: JsonInput) -> Tuple[str, Dict[str, Any]]:
+        return (falcon.HTTP_200, self.app.create_account_identifier(account_id, input))
 
     @rest_handler
     def on_get_balances(self, account_id: str, input: JsonInput) -> Tuple[str, Dict[str, int]]:
@@ -74,20 +76,9 @@ class Endpoints:
         resp.set_header(offchain.X_REQUEST_ID, request_id)
         request_sender_address = req.get_header(offchain.X_REQUEST_SENDER_ADDRESS)
         input_data = req.stream.read()
-        try:
-            if not request_id:
-                raise offchain.protocol_error(
-                    offchain.ErrorCode.missing_http_header, "missing %s" % offchain.X_REQUEST_ID
-                )
-            if not offchain.UUID_REGEX.match(request_id):
-                raise offchain.protocol_error(
-                    offchain.ErrorCode.invalid_http_header, "invalid %s" % offchain.X_REQUEST_ID
-                )
-            resp_obj = self.app.offchain_api(request_sender_address, input_data)
-        except offchain.Error as e:
-            self.app.logger.info(input_data)
-            self.app.logger.exception(e)
-            resp_obj = offchain.reply_request(cid=None, err=e.obj)
+
+        resp_obj = self.app.offchain_api(request_id, request_sender_address, input_data)
+        if resp_obj.error is not None:
             resp.status = falcon.HTTP_400
         resp.body = self.app.jws_serialize(resp_obj)
 
@@ -101,7 +92,7 @@ def falcon_api(app: App, disable_events_api: bool = False) -> falcon.API:
     api.add_static_route("/", base_path)
     api.add_route("/", endpoints, suffix="index")
     api.add_route("/accounts", endpoints, suffix="accounts")
-    for res in ["balances", "payments", "payment_uris", "events"]:
+    for res in ["balances", "payments", "account_identifiers", "events"]:
         if res == "events" and disable_events_api:
             continue
         api.add_route("/accounts/{account_id}/%s" % res, endpoints, suffix=res)
