@@ -6,11 +6,11 @@ from typing import List, Tuple, Dict, Optional, Any
 from json.decoder import JSONDecodeError
 from .store import InMemoryStore, NotFoundError
 from .diem_account import DiemAccount
-from .models import PaymentUri, Subaddress, Account, Transaction, Event, KycSample, Payment, PaymentCommand
+from .models import Subaddress, Account, Transaction, Event, KycSample, PaymentCommand
 from .event_puller import EventPuller
 from .json_input import JsonInput
 from ... import LocalAccount
-from .... import jsonrpc, offchain, utils, identifier
+from .... import jsonrpc, offchain, utils
 from ....offchain import KycDataObject, Status, AbortCode, CommandResponseObject
 import threading, logging, numpy
 
@@ -83,14 +83,42 @@ class Base:
 
 
 class OffChainAPI(Base):
-    def offchain_api(self, request_sender_address: str, request_bytes: bytes) -> CommandResponseObject:
-        request = self.offchain.deserialize_inbound_request(request_sender_address, request_bytes)
-        getattr(self, "_handle_offchain_%s" % utils.to_snake(request.command_type))(request_sender_address, request)
-        return offchain.reply_request(cid=request.cid)
+    def offchain_api(self, request_id: str, request_sender_address: str, request_bytes: bytes) -> CommandResponseObject:
+        cid = None
+        try:
+            if not request_id:
+                raise offchain.protocol_error(
+                    offchain.ErrorCode.missing_http_header, "missing %s" % offchain.X_REQUEST_ID
+                )
+            if not offchain.UUID_REGEX.match(request_id):
+                raise offchain.protocol_error(
+                    offchain.ErrorCode.invalid_http_header, "invalid %s" % offchain.X_REQUEST_ID
+                )
+
+            request = self.offchain.deserialize_inbound_request(request_sender_address, request_bytes)
+            cid = request.cid
+            handler = "_handle_offchain_%s" % utils.to_snake(request.command_type)
+            if not hasattr(self, handler):
+                raise offchain.protocol_error(
+                    offchain.ErrorCode.unknown_command_type,
+                    "unknown command_type: %s" % request.command_type,
+                    field="command_type",
+                )
+            getattr(self, handler)(request_sender_address, request)
+            return offchain.reply_request(cid=cid)
+        except offchain.Error as e:
+            self.logger.info(request_bytes)
+            self.logger.exception(e)
+            return offchain.reply_request(cid=cid, err=e.obj)
 
     def jws_serialize(self, resp: CommandResponseObject) -> bytes:
         return offchain.jws.serialize(resp, self.diem_account.account.compliance_key.sign)
 
+    def _handle_offchain_ping_command(
+        self, request_sender_address: str, request: offchain.CommandRequestObject
+    ) -> None:
+        pass
+
     def _handle_offchain_payment_command(
         self, request_sender_address: str, request: offchain.CommandRequestObject
     ) -> None:
@@ -170,6 +198,7 @@ class BackgroundTasks(OffChainAPI):
             currency=txn.currency,
             amount=txn.amount,
             status=Transaction.Status.completed,
+            type=Transaction.Type.sent_payment,
         )
         self.store.update(txn, status=Transaction.Status.completed)
 
@@ -294,24 +323,26 @@ class App(BackgroundTasks):
         if balances:
             for c, a in balances.items():
                 self._create_transaction(
-                    account.id, Transaction.Status.completed, JsonInput({"currency": c, "amount": a})
+                    account.id,
+                    Transaction.Status.completed,
+                    JsonInput({"currency": c, "amount": a}),
+                    type=Transaction.Type.deposit,
                 )
         return {"id": account.id}
 
-    def create_account_payment(self, account_id: str, data: JsonInput) -> Payment:
+    def create_account_payment(self, account_id: str, data: JsonInput) -> Dict[str, Any]:
         self.store.find(Account, id=account_id)
         payee = data.get("payee", str, self._validate_account_identifier)
-        txn = self._create_transaction(account_id, Transaction.Status.pending, data, payee=payee)
-        return Payment(id=txn.id, account_id=account_id, payee=payee, currency=txn.currency, amount=txn.amount)
+        txn = self._create_transaction(
+            account_id, Transaction.Status.pending, data, type=Transaction.Type.sent_payment, payee=payee
+        )
+        return {"id": txn.id}
 
-    def create_account_payment_uri(self, account_id: str, data: JsonInput) -> PaymentUri:
-        currency = data.get_nullable("currency", str, self._validate_currency_code)
-        amount = data.get_nullable("amount", int, self._validate_amount)
+    def create_account_identifier(self, account_id: str, data: JsonInput) -> Dict[str, str]:
         self.store.find(Account, id=account_id)
         sub = self._gen_subaddress(account_id)
         diem_acc_id = self.diem_account.account.account_identifier(sub.subaddress_hex)
-        uri = identifier.encode_intent(diem_acc_id, currency, amount)
-        return PaymentUri(id=sub.id, account_id=account_id, payment_uri=uri)
+        return {"account_identifier": diem_acc_id}
 
     def get_account_balances(self, account_id: str) -> Dict[str, int]:
         self.store.find(Account, id=account_id)
@@ -321,7 +352,12 @@ class App(BackgroundTasks):
         return self.store.find_all(Event, account_id=account_id)
 
     def _create_transaction(
-        self, account_id: str, status: str, data: JsonInput, payee: Optional[str] = None
+        self,
+        account_id: str,
+        status: str,
+        data: JsonInput,
+        type: Transaction.Type,
+        payee: Optional[str] = None,
     ) -> Transaction:
         return self.store.create(
             Transaction,
@@ -330,5 +366,6 @@ class App(BackgroundTasks):
             amount=data.get("amount", int, self._validate_amount),
             payee=payee,
             status=status,
+            type=type,
             before_create=self._validate_account_balance,
         )
